Index: code/branches/tgidronFS16/data/levels/templates/spaceshipHover.oxt
===================================================================
--- code/branches/tgidronFS16/data/levels/templates/spaceshipHover.oxt	(revision 11150)
+++ code/branches/tgidronFS16/data/levels/templates/spaceshipHover.oxt	(revision 11151)
@@ -18,7 +18,7 @@
    reloadwaittime      = 0.5
 
-   primaryThrust     = 200
-   auxilaryThrust    = 30
-   rotationThrust    = 25
+   primaryThrust     = 100
+   auxilaryThrust    = 1
+   rotationThrust    = 30
 
    jumpBoost = 90
@@ -33,5 +33,5 @@
 
    collisionType     = "dynamic"
-   mass              = 100
+   mass              = 1000
    linearDamping     = 0.2
    angularDamping    = 0.9999999
@@ -79,5 +79,5 @@
    boostfactor    = 2
 
-   speedfront     = 90
+   speedfront     = 120
    speedback      =  40
    speedleftright =  40
@@ -86,5 +86,5 @@
    accelerationfront     = 500
    accelerationbrake     = 500
-   accelerationback      =  125
+   accelerationback      =  250
    accelerationleftright =  125
    accelerationupdown    =  125
Index: code/branches/tgidronFS16/data/overlays/HoverHUD.oxo
===================================================================
--- code/branches/tgidronFS16/data/overlays/HoverHUD.oxo	(revision 11150)
+++ code/branches/tgidronFS16/data/overlays/HoverHUD.oxo	(revision 11151)
@@ -39,8 +39,20 @@
      iconmaterial      = "Orxonox/BarIconHealth"
     >
+
       <BarColour position = 0.0 colour = "0.7,0.2,0.2" />
       <BarColour position = 0.5 colour = "0.7,0.7,0.2" />
       <BarColour position = 1.0 colour = "0.2,0.7,0.2" />
     </HUDHealthBar>
+
+
+    <HUDNavigation
+     name          = "Navigation"
+     correctaspect = true
+     font          = "Monofur"
+     textsize      = 0.02
+     navMarkerSize = 0.03
+     aimMarkerSize = 0.02
+    />
+
  </OverlayGroup>
 </Template>
Index: code/branches/tgidronFS16/src/modules/hover/FlagHUD.cc
===================================================================
--- code/branches/tgidronFS16/src/modules/hover/FlagHUD.cc	(revision 11150)
+++ code/branches/tgidronFS16/src/modules/hover/FlagHUD.cc	(revision 11151)
@@ -54,6 +54,6 @@
         this->overlay_->add2D(this->panel_);
 
-        this->flagCount_ = 5;
-        setFlagCount(5);
+        this->flagCount_ = 1;
+        setFlagCount(1);
     }
 
Index: code/branches/tgidronFS16/src/modules/hover/Hover.h
===================================================================
--- code/branches/tgidronFS16/src/modules/hover/Hover.h	(revision 11150)
+++ code/branches/tgidronFS16/src/modules/hover/Hover.h	(revision 11151)
@@ -55,4 +55,10 @@
                 { this->origin_ = origin; }
 
+            void start();
+            void startLevel();
+            void levelUp();
+            void endLevel();
+
+
             inline int getNumberOfFlags() const
                 { return this->numberOfFlags_; }
@@ -63,4 +69,11 @@
             int numberOfFlags_;
             bool firstTick_;
+            int level;
+            int lives;
+            int flagsTaken;
+
+            int cellSize;
+            int cellHeight;
+            int numCells;
     };
 }
Index: code/branches/tgidronFS16/src/modules/hover/HoverShip.cc
===================================================================
--- code/branches/tgidronFS16/src/modules/hover/HoverShip.cc	(revision 11150)
+++ code/branches/tgidronFS16/src/modules/hover/HoverShip.cc	(revision 11151)
@@ -33,4 +33,5 @@
 #include "core/CoreIncludes.h"
 #include "core/XMLPort.h"
+//#include "NewHumanController.h"
 
 #include <BulletCollision/NarrowPhaseCollision/btManifoldPoint.h>
@@ -112,4 +113,5 @@
         if (bBoost && this->isFloor_)
         {
+
             this->setVelocity(
                 this->getVelocity().x,

Index: code/branches/tgidronFS16/src/modules/hover/Hover.cc
===================================================================
--- code/branches/tgidronFS16/src/modules/hover/Hover.cc	(revision 11150)
+++ code/branches/tgidronFS16/src/modules/hover/Hover.cc	(revision 11151)
@@ -33,5 +33,5 @@
 
 #include "Hover.h"
-
+#include "chat/ChatManager.h"
 #include "HoverOrigin.h"
 #include "HoverWall.h"
@@ -39,4 +39,5 @@
 #include "MazeGenerator.h"
 #include "core/CoreIncludes.h"
+#include "gamestates/GSLevel.h"
 
 namespace orxonox
@@ -51,19 +52,26 @@
         this->numberOfFlags_ = 1;
         this->firstTick_ = true;
+        level = 1; //start at level 1
+        flagsTaken = 0;// took 0 flags in the beginning
+
+        numCells = 0;
+        cellSize = 0;
+        cellHeight = 0;
 
         this->setHUDTemplate("HoverHUD");
+
+        
     }
 
-    void Hover::tick(float dt)
+    void Hover::start()
     {
-        SUPER(Hover, tick, dt);
-
+        Gametype::start();
         if(this->firstTick_ && this->origin_)
         {
             this->firstTick_ = false;
 
-            int numCells = this->origin_->getNumCells();
-            int cellSize = this->origin_->getCellSize();
-            int cellHeight = this->origin_->getCellHeight();
+            numCells = this->origin_->getNumCells();
+            cellSize = this->origin_->getCellSize();
+            cellHeight = this->origin_->getCellHeight();
 
             MazeGenerator generator(numCells);
@@ -94,6 +102,6 @@
             }
 
-            //Generate 5 flags randomly
-            for ( int i = 0; i < 5; i++ )
+            //Generate 5 flags randomly (test only 1 flag)
+            for ( int i = 0; i < 1; i++ )
             {
                 HoverFlag* flag = new HoverFlag(origin_->getContext());
@@ -102,5 +110,24 @@
             }
 
-        }//firsttick end
+        } 
+    }
+
+
+
+    void Hover::startLevel(){
+        //Generate 5 flags randomly (test only 1 flag)
+            for ( int i = 0; i < 1; i++ )
+            {
+                HoverFlag* flag = new HoverFlag(origin_->getContext());
+                flag->init(rand()%numCells, rand()%numCells, cellSize);
+                flags_.push_back(flag);
+            }
+
+    }
+
+    void Hover::tick(float dt)
+    {
+        SUPER(Hover, tick, dt);
+
 
         // Check if ship collided with one of the flags
@@ -109,7 +136,21 @@
                 flags_[i]->destroyLater();
                 flags_.erase (flags_.begin()+i);
+                if(flags_.size()<=0){
+                    ChatManager::message("Level Up!");
+                    
+                    levelUp();
+                    //GSLevel::startMainMenu();
+                }
             }
+
         }
         numberOfFlags_ = flags_.size();
     }
+
+    void Hover::levelUp()
+    {
+        level++;
+        startLevel();
+
+    }
 }